==> alg-common-1.17.3-20190619.070102-1-sources.jar: cn/com/duiba/nezha/alg/common/model/pacing/HelpMeasureResult.java <==
package cn.com.duiba.nezha.alg.common.model.pacing;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.Set;

public class HelpMeasureResult {

    Long advertId;
    Long orientId;
    Long appId;
    Long slotId;

    //异常
    Double costException;//消耗异常指数
    Double costConvertException;//成本异常指数
    Double fatalException;//严重异常

    Set<Integer> helpBySelfType;//1:系统精准自救 2：系统尝试自救 3：提示人工自救

//    Double biddingTimesRecduceException;//竞价次数降低
//    Double preCvrReduceException; //pre_cvr降低
//    Double stableFactorException; //维稳因子低
//    Double basePriceException;//触发底价消耗占比高
//
//    Double feeReduceException;
//    Double afeeReduceException;
//    Double preCtrReduceException; //pre_ctr降低
//    Double lauOrderException;//发券次序降低
//    Double orientAppExposureException; //媒体曝光量大减
//
//    String orientLimitAppException;//媒体限流
//    String appShieldOrientException;//被媒体屏蔽
//    Double orientBudgetException;//预算不足
//    String noReasonException; //未知异常

    //措施
    Boolean isExpand;//托管是否拓量orient
    Double orientRatioWeight;//拓量无历史数据定向率加权因子orient
    Double isReorient;//拓量-未定向重新定向orient
    Double isBlackRealse; //拓量-黑名单orient
//    Integer expandOrient;//拓量的配置1 原有的配置0

    Set<Integer> remindAE1;//提示AE人工自救-返回给nezha:1竞价次数,4afee
    Set<Integer> remindAE2;//提示AE人工自救-返回给nezha:2点击率,3fee
    Double feeWeightFactor0;//出价加权因子slot_orient
    Double feeWeightFactor1;//出价加权因子app_orient

    Boolean isResetStableFactor;//重置维稳因子orient_app
    Boolean isBasePriceException; //是否流量放弃slot_orient
    Boolean isCancelStableRelate; //是否取消维稳联动orient_app


    public HelpMeasureResult() {
        this.advertId = 0L;
        this.orientId = 0L;
        this.appId = 0L;
        this.slotId = 0L;
        this.costException = 0.0;//消耗异常指数
        this.costConvertException = 0.0;//成本异常指数
        this.fatalException = 0.0;//
        this.isExpand = false;//托管是否拓量orient
//        this.expandOrient = 0;
        this.orientRatioWeight = 1.0;//拓量无历史数据定向率加权因子orient
        this.isReorient = 1.0;//拓量-未定向重新定向orient
        this.isBlackRealse = 1.0; //拓量-黑名单orient
        this.feeWeightFactor0 = 1.0;//出价加权因子slot_orient
        this.feeWeightFactor1 = 1.0;//出价加权因子app_orient
        this.isResetStableFactor = false;//重置维稳因子orient_app
        this.isBasePriceException = false; //是否流量放弃slot_orient
        this.isCancelStableRelate = false; //是否取消维稳联动orient_app
        this.helpBySelfType = new HashSet<Integer>();
        this.remindAE1 = new HashSet<Integer>();
        this.remindAE2 = new HashSet<Integer>();
    }


    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getOrientId() {
        return orientId;
    }

    public void setOrientId(Long orientId) {
        this.orientId = orientId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Double getCostException() {
        return costException;
    }

    public void setCostException(Double costException) {
        this.costException = costException;
    }

    public Double getCostConvertException() {
        return costConvertException;
    }

    public void setCostConvertException(Double costConvertException) {
        this.costConvertException = costConvertException;
    }

    public Double getFatalException() {
        return fatalException;
    }

    public void setFatalException(Double fatalException) {
        this.fatalException = fatalException;
    }

    public Set<Integer> getHelpBySelfType() {
        return helpBySelfType;
    }

    public void setHelpBySelfType(Set<Integer> helpBySelfType) {
        this.helpBySelfType = helpBySelfType;
    }

    public Boolean getExpand() {
        return isExpand;
    }

    public void setExpand(Boolean expand) {
        isExpand = expand;
    }

    public Double getOrientRatioWeight() {
        return orientRatioWeight;
    }

    public void setOrientRatioWeight(Double orientRatioWeight) {
        this.orientRatioWeight = orientRatioWeight;
    }

    public Double getIsReorient() {
        return isReorient;
    }

    public void setIsReorient(Double isReorient) {
        this.isReorient = isReorient;
    }

    public Double getIsBlackRealse() {
        return isBlackRealse;
    }

    public void setIsBlackRealse(Double isBlackRealse) {
        this.isBlackRealse = isBlackRealse;
    }

    public Set<Integer> getRemindAE1() {
        return remindAE1;
    }

    public void setRemindAE1(Set<Integer> remindAE1) {
        this.remindAE1 = remindAE1;
    }

    public Set<Integer> getRemindAE2() {
        return remindAE2;
    }

    public void setRemindAE2(Set<Integer> remindAE2) {
        this.remindAE2 = remindAE2;
    }

    public Double getFeeWeightFactor0() {
        return feeWeightFactor0;
    }

    public void setFeeWeightFactor0(Double feeWeightFactor0) {
        this.feeWeightFactor0 = feeWeightFactor0;
    }

    public Double getFeeWeightFactor1() {
        return feeWeightFactor1;
    }

    public void setFeeWeightFactor1(Double feeWeightFactor1) {
        this.feeWeightFactor1 = feeWeightFactor1;
    }

    public Boolean getResetStableFactor() {
        return isResetStableFactor;
    }

    public void setResetStableFactor(Boolean resetStableFactor) {
        isResetStableFactor = resetStableFactor;
    }

    public Boolean getBasePriceException() {
        return isBasePriceException;
    }

    public void setBasePriceException(Boolean basePriceException) {
        isBasePriceException = basePriceException;
    }

    public Boolean getCancelStableRelate() {
        return isCancelStableRelate;
    }

    public void setCancelStableRelate(Boolean cancelStableRelate) {
        isCancelStableRelate = cancelStableRelate;
    }


//    public Integer getExpandOrient() {
//        return expandOrient;
//    }
//
//    public void setExpandOrient(Integer expandOrient) {
//        this.expandOrient = expandOrient;
//    }
//


}

==> alg-common-1.48.8-sources.jar: cn/com/duiba/nezha/alg/common/model/pacing/HelpMeasureResult.java <==
package cn.com.duiba.nezha.alg.common.model.pacing;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.Set;

public class HelpMeasureResult {

    Long advertId;
    Long orientId;
    Long appId;
    Long slotId;

    //异常
    Double costException;//消耗异常指数
    Double costConvertException;//成本异常指数
    Double fatalException;//严重异常

    Set<Integer> helpBySelfType;//1:系统精准自救 2：系统尝试自救 3：提示人工自救

//    Double biddingTimesRecduceException;//竞价次数降低
//    Double preCvrReduceException; //pre_cvr降低
//    Double stableFactorException; //维稳因子低
//    Double basePriceException;//触发底价消耗占比高
//
//    Double feeReduceException;
//    Double afeeReduceException;
//    Double preCtrReduceException; //pre_ctr降低
//    Double lauOrderException;//发券次序降低
//    Double orientAppExposureException; //媒体曝光量大减
//
//    String orientLimitAppException;//媒体限流
//    String appShieldOrientException;//被媒体屏蔽
//    Double orientBudgetException;//预算不足
//    String noReasonException; //未知异常

    //措施
    Boolean isExpand;//托管是否拓量orient
    Double orientRatioWeight;//拓量无历史数据定向率加权因子orient
    Double isReorient;//拓量-未定向重新定向orient
    Double isBlackRealse; //拓量-黑名单orient
//    Integer expandOrient;//拓量的配置1 原有的配置0

    Set<Integer> remindAE1;//配置维度提示AE人工自救-返回给nezha:1竞价次数,4prectr,5precvr,6afee,7发券次序
    Set<Integer> remindAE2;//配置广告位维度提示AE人工自救-返回给nezha:2点击率,3fee
    Double feeWeightFactor0;//出价加权因子slot_orient
    Double feeWeightFactor1;//出价加权因子app_orient

    Boolean isResetStableFactor;//重置维稳因子orient_app
    Boolean isBasePriceException; //是否流量放弃slot_orient
    Boolean isCancelStableRelate; //是否取消维稳联动orient_app

    ReduceRateDo orientBiddingTimesDo;//竞价次数
    ReduceRateDo orientPreCtrDo;//pre_Ctr
    ReduceRateDo orientPreCvrDo;//pre_Cvr
    ReduceRateDo orientAfeeDo;//目标转化出价
    ReduceRateDo orientLaunchOrderDo;//发券次序为1


    public class ReduceRateDo{


        Integer remindType;//1竞价次数,4prectr,5precvr,6afee,7发券次序
        Double todayValue;//今日
//        Double yestodayValue;//昨日
//        Double avg7dayValue;//过去7日
        Double reduceRatio1;//今天比昨天
        Double reduceRatio2;//今天比过去7日

        public ReduceRateDo(){

        }

        public ReduceRateDo(Integer remindType, Double todayValue, Double reduceRatio1, Double reduceRatio2) {
            this.remindType = remindType;
            this.todayValue = todayValue;
            this.reduceRatio1 = reduceRatio1;
            this.reduceRatio2 = reduceRatio2;
        }
        public Integer getRemindType() {
            return remindType;
        }

        public void setRemindType(Integer remindType) {
            this.remindType = remindType;
        }

        public Double getTodayValue() {
            return todayValue;
        }

        public void setTodayValue(Double todayValue) {
            this.todayValue = todayValue;
        }

        public Double getReduceRatio1() {
            return reduceRatio1;
        }

        public void setReduceRatio1(Double reduceRatio1) {
            this.reduceRatio1 = reduceRatio1;
        }

        public Double getReduceRatio2() {
            return reduceRatio2;
        }

        public void setReduceRatio2(Double reduceRatio2) {
            this.reduceRatio2 = reduceRatio2;
        }

    }


    public HelpMeasureResult() {
        this.advertId = 0L;
        this.orientId = 0L;
        this.appId = 0L;
        this.slotId = 0L;
        this.costException = 0.0;//消耗异常指数
        this.costConvertException = 0.0;//成本异常指数
        this.fatalException = 0.0;//
        this.isExpand = false;//托管是否拓量orient
//        this.expandOrient = 0;
        this.orientRatioWeight = 1.0;//拓量无历史数据定向率加权因子orient
        this.isReorient = 1.0;//拓量-未定向重新定向orient
        this.isBlackRealse = 1.0; //拓量-黑名单orient
        this.feeWeightFactor0 = 1.0;//出价加权因子slot_orient
        this.feeWeightFactor1 = 1.0;//出价加权因子app_orient
        this.isResetStableFactor = false;//重置维稳因子orient_app
        this.isBasePriceException = false; //是否流量放弃slot_orient
        this.isCancelStableRelate = false; //是否取消维稳联动orient_app
        this.helpBySelfType = new HashSet<Integer>();
        this.remindAE1 = new HashSet<Integer>();
        this.remindAE2 = new HashSet<Integer>();
        this.orientBiddingTimesDo = new ReduceRateDo(0,0.0,0.0,0.0);
        this.orientPreCtrDo = new ReduceRateDo(0,0.0,0.0,0.0);
        this.orientPreCvrDo = new ReduceRateDo(0,0.0,0.0,0.0);
        this.orientAfeeDo = new ReduceRateDo(0,0.0,0.0,0.0);
        this.orientLaunchOrderDo = new ReduceRateDo(0,0.0,0.0,0.0);

    }


    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getOrientId() {
        return orientId;
    }

    public void setOrientId(Long orientId) {
        this.orientId = orientId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Double getCostException() {
        return costException;
    }

    public void setCostException(Double costException) {
        this.costException = costException;
    }

    public Double getCostConvertException() {
        return costConvertException;
    }

    public void setCostConvertException(Double costConvertException) {
        this.costConvertException = costConvertException;
    }

    public Double getFatalException() {
        return fatalException;
    }

    public void setFatalException(Double fatalException) {
        this.fatalException = fatalException;
    }

    public Set<Integer> getHelpBySelfType() {
        return helpBySelfType;
    }

    public void setHelpBySelfType(Set<Integer> helpBySelfType) {
        this.helpBySelfType = helpBySelfType;
    }

    public Boolean getExpand() {
        return isExpand;
    }

    public void setExpand(Boolean expand) {
        isExpand = expand;
    }

    public Double getOrientRatioWeight() {
        return orientRatioWeight;
    }

    public void setOrientRatioWeight(Double orientRatioWeight) {
        this.orientRatioWeight = orientRatioWeight;
    }

    public Double getIsReorient() {
        return isReorient;
    }

    public void setIsReorient(Double isReorient) {
        this.isReorient = isReorient;
    }

    public Double getIsBlackRealse() {
        return isBlackRealse;
    }

    public void setIsBlackRealse(Double isBlackRealse) {
        this.isBlackRealse = isBlackRealse;
    }

    public Set<Integer> getRemindAE1() {
        return remindAE1;
    }

    public void setRemindAE1(Set<Integer> remindAE1) {
        this.remindAE1 = remindAE1;
    }

    public Set<Integer> getRemindAE2() {
        return remindAE2;
    }

    public void setRemindAE2(Set<Integer> remindAE2) {
        this.remindAE2 = remindAE2;
    }

    public Double getFeeWeightFactor0() {
        return feeWeightFactor0;
    }

    public void setFeeWeightFactor0(Double feeWeightFactor0) {
        this.feeWeightFactor0 = feeWeightFactor0;
    }

    public Double getFeeWeightFactor1() {
        return feeWeightFactor1;
    }

    public void setFeeWeightFactor1(Double feeWeightFactor1) {
        this.feeWeightFactor1 = feeWeightFactor1;
    }

    public Boolean getResetStableFactor() {
        return isResetStableFactor;
    }

    public void setResetStableFactor(Boolean resetStableFactor) {
        isResetStableFactor = resetStableFactor;
    }

    public Boolean getBasePriceException() {
        return isBasePriceException;
    }

    public void setBasePriceException(Boolean basePriceException) {
        isBasePriceException = basePriceException;
    }

    public Boolean getCancelStableRelate() {
        return isCancelStableRelate;
    }

    public void setCancelStableRelate(Boolean cancelStableRelate) {
        isCancelStableRelate = cancelStableRelate;
    }
    public ReduceRateDo getOrientBiddingTimesDo() {
        return orientBiddingTimesDo;
    }

    public void setOrientBiddingTimesDo(ReduceRateDo orientBiddingTimesDo) {
        this.orientBiddingTimesDo = orientBiddingTimesDo;
    }

    public ReduceRateDo getOrientPreCtrDo() {
        return orientPreCtrDo;
    }

    public void setOrientPreCtrDo(ReduceRateDo orientPreCtrDo) {
        this.orientPreCtrDo = orientPreCtrDo;
    }

    public ReduceRateDo getOrientPreCvrDo() {
        return orientPreCvrDo;
    }

    public void setOrientPreCvrDo(ReduceRateDo orientPreCvrDo) {
        this.orientPreCvrDo = orientPreCvrDo;
    }

    public ReduceRateDo getOrientAfeeDo() {
        return orientAfeeDo;
    }

    public void setOrientAfeeDo(ReduceRateDo orientAfeeDo) {
        this.orientAfeeDo = orientAfeeDo;
    }

    public ReduceRateDo getOrientLaunchOrderDo() {
        return orientLaunchOrderDo;
    }

    public void setOrientLaunchOrderDo(ReduceRateDo orientLaunchOrderDo) {
        this.orientLaunchOrderDo = orientLaunchOrderDo;
    }



}
